==> org-lsst-ccs-subsystem-fcs-buses-1.4.4-sources.jar: org/lsst/ccs/subsystems/fcs/loader/config/LoaderClampConfig.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.lsst.ccs.subsystems.fcs.loader.config;

import java.io.Serializable;

/**
 *
 * @author virieux
 */
public class LoaderClampConfig implements Serializable {
    
    String name;
    int clampPosition;
    int minPosition,maxPosition,positionToOpen,positionToClose,positionToClamp;
    long timeoutToOpen, timeoutToClose, timeoutToClamp, timeoutToGoHome;
    public LoaderHookConfig hookConfig1;
    public LoaderHookConfig hookConfig2;
    public LoaderHookConfig hookConfig3;
    public LoaderHookConfig hookConfig4;


    public LoaderClampConfig(int minPosition, int maxPosition, int positionToOpen, int positionToClose, int positionToClamp, long timeoutToOpen, long timeoutToClose, long timeoutToClamp, long timeoutToGoHome, LoaderHookConfig hookConfig1, LoaderHookConfig hookConfig2, LoaderHookConfig hookConfig3, LoaderHookConfig hookConfig4) {
        this.minPosition = minPosition;
        this.maxPosition = maxPosition;
        this.positionToOpen = positionToOpen;
        this.positionToClose = positionToClose;
        this.positionToClamp = positionToClamp;
        this.timeoutToOpen = timeoutToOpen;
        this.timeoutToClose = timeoutToClose;
        this.timeoutToClamp = timeoutToClamp;
        this.timeoutToGoHome = timeoutToGoHome;
        this.hookConfig1 = hookConfig1;
        this.hookConfig2 = hookConfig2;
        this.hookConfig3 = hookConfig3;
        this.hookConfig4 = hookConfig4;
    }
    
    

    public int getMinPosition() {
        return minPosition;
    }

    public int getMaxPosition() {
        return maxPosition;
    }

    public int getPositionToOpen() {
        return positionToOpen;
    }

    public int getPositionToClose() {
        return positionToClose;
    }

    public int getPositionToClamp() {
        return positionToClamp;
    }

    public long getTimeoutToOpen() {
        return timeoutToOpen;
    }

    public long getTimeoutToClose() {
        return timeoutToClose;
    }

    public long getTimeoutToClamp() {
        return timeoutToClamp;
    }

    public long getTimeoutToGoHome() {
        return timeoutToGoHome;
    }


    
    
    
    
    
    
    
    
    
    
    
    
}

==> org-lsst-ccs-subsystem-fcs-buses-1.6.1-sources.jar: org/lsst/ccs/subsystems/fcs/loader/config/LoaderClampConfig.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.lsst.ccs.subsystems.fcs.loader.config;

import java.io.Serializable;

/**
 *
 * @author virieux
 */
public class LoaderClampConfig implements Serializable {
    
    String name;
    int clampPosition;
    int minPosition,maxPosition,positionToOpen,positionToClose,positionToClamp;
    int minCurrent, maxCurrent;
    long timeoutToOpen, timeoutToClose, timeoutToClamp, timeoutToGoHome;
    public LoaderHookConfig hookConfig1;
    public LoaderHookConfig hookConfig2;
    public LoaderHookConfig hookConfig3;
    public LoaderHookConfig hookConfig4;


    public LoaderClampConfig(int minPosition, int maxPosition, 
            int minCurrent, int maxCurrent,
            int positionToOpen, int positionToClose, int positionToClamp, 
            long timeoutToOpen, long timeoutToClose, long timeoutToClamp, 
            long timeoutToGoHome, 
            LoaderHookConfig hookConfig1, 
            LoaderHookConfig hookConfig2, 
            LoaderHookConfig hookConfig3, 
            LoaderHookConfig hookConfig4) {
        this.minPosition = minPosition;
        this.maxPosition = maxPosition;
        this.minCurrent = minCurrent;
        this.maxCurrent = maxCurrent;
        this.positionToOpen = positionToOpen;
        this.positionToClose = positionToClose;
        this.positionToClamp = positionToClamp;
        this.timeoutToOpen = timeoutToOpen;
        this.timeoutToClose = timeoutToClose;
        this.timeoutToClamp = timeoutToClamp;
        this.timeoutToGoHome = timeoutToGoHome;
        this.hookConfig1 = hookConfig1;
        this.hookConfig2 = hookConfig2;
        this.hookConfig3 = hookConfig3;
        this.hookConfig4 = hookConfig4;
    }

    public int getMinCurrent() {
        return minCurrent;
    }

    public int getMaxCurrent() {
        return maxCurrent;
    }
    
    

    public int getMinPosition() {
        return minPosition;
    }

    public int getMaxPosition() {
        return maxPosition;
    }

    public int getPositionToOpen() {
        return positionToOpen;
    }

    public int getPositionToClose() {
        return positionToClose;
    }

    public int getPositionToClamp() {
        return positionToClamp;
    }

    public long getTimeoutToOpen() {
        return timeoutToOpen;
    }

    public long getTimeoutToClose() {
        return timeoutToClose;
    }

    public long getTimeoutToClamp() {
        return timeoutToClamp;
    }

    public long getTimeoutToGoHome() {
        return timeoutToGoHome;
    }


    
    
    
    
    
    
    
    
    
    
    
    
}
